[PATCH] dbgeng: Added DebugCreateEx() stub

Nikolay Sivov nsivov at codeweavers.com
Wed Sep 6 04:19:30 CDT 2017


Signed-off-by: Nikolay Sivov <nsivov at codeweavers.com>
---

For https://bugs.winehq.org/show_bug.cgi?id=43649

 dlls/dbgeng/dbgeng.c    | 18 ++++++++++++++----
 dlls/dbgeng/dbgeng.spec |  2 +-
 2 files changed, 15 insertions(+), 5 deletions(-)

diff --git a/dlls/dbgeng/dbgeng.spec b/dlls/dbgeng/dbgeng.spec
index f2f735cb15..14dbc33476 100644
--- a/dlls/dbgeng/dbgeng.spec
+++ b/dlls/dbgeng/dbgeng.spec
@@ -2,5 +2,5 @@
 @ stdcall DebugConnect(str ptr ptr)
 @ stub DebugConnectWide
 @ stdcall DebugCreate(ptr ptr)
-@ stub DebugCreateEx
+@ stdcall DebugCreateEx(ptr long ptr)
 @ stdcall DebugExtensionInitialize(ptr ptr)
diff --git a/dlls/dbgeng/dbgeng.c b/dlls/dbgeng/dbgeng.c
index b08be75900..6ac93604d5 100644
--- a/dlls/dbgeng/dbgeng.c
+++ b/dlls/dbgeng/dbgeng.c
@@ -58,8 +58,8 @@ HRESULT WINAPI DebugExtensionInitialize(ULONG * pVersion, ULONG * pFlags)
 * Creating Debug Engine client object
 *
 * PARAMS
 *   InterfaceId   [I] Interface Id of debugger client
 *   pInterface    [O] Pointer to interface as requested via InterfaceId
 *
 * RETURNS
 *   Success: S_OK
@@ -68,15 +68,25 @@ HRESULT WINAPI DebugExtensionInitialize(ULONG * pVersion, ULONG * pFlags)
 * BUGS
 *   Unimplemented
 */
-HRESULT WINAPI DebugCreate(REFIID InterfaceId, PVOID * pInterface)
+HRESULT WINAPI DebugCreate(REFIID riid, void **obj)
 {
-    FIXME("(%p,%p): stub\n", InterfaceId, pInterface);
+    FIXME("(%s, %p): stub\n", debugstr_guid(riid), obj);
 
     SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
 
     return E_NOTIMPL;
 }
 
+/************************************************************
+*                    DebugCreateEx   (DBGENG.@)
+*/
+HRESULT WINAPI DebugCreateEx(REFIID riid, DWORD flags, void **obj)
+{
+    FIXME("(%s, %#x, %p): stub\n", debugstr_guid(riid), flags, obj);
+
+    return E_NOTIMPL;
+}
+
 /************************************************************
 *                    DebugConnect   (DBGENG.@)
 *
@@ -58,8 +58,8 @@ HRESULT WINAPI DebugExtensionInitialize(ULONG * pVersion, ULONG * pFlags)
 *
 * PARAMS
-*   InterfaceId   [I] Interface Id of debugger client
-*   pInterface    [O] Pointer to interface as requested via InterfaceId
+*   riid   [I] Interface Id of debugger client
+*   obj    [O] Pointer to interface as requested via riid
 *
 * RETURNS
-- 
2.14.1




More information about the wine-patches mailing list